This patch reverses the standard resv logic for channels, making any
channel not listed in a resv{} block banned from the server.

To install:
$ cd /path/to/ircd-ratbox-1.1rc5
$ patch -p1 </path/to/r1.1rc5-reversejupe.diff

- W. Campbell (Hwy)
diff -uNrd ircd-ratbox-1.1rc5.dist/doc/example.conf ircd-ratbox-1.1rc5/doc/example.conf
--- ircd-ratbox-1.1rc5.dist/doc/example.conf	Thu Feb 27 15:48:22 2003
+++ ircd-ratbox-1.1rc5/doc/example.conf	Wed Apr 16 21:05:09 2003
@@ -501,14 +501,26 @@
 };
 
 /* resv {}: nicks and channels users may not use/join (OLD Q:) */
+/* NOTE:  If this line is here, the server was patched to have reverse
+** logic for resv{}.  In this case, any channels NOT listed here are
+** blocked from users.  If 'no_oper_resv' is set to yes in the channels{}
+** block, opers can join any channel.  If not, then opers are restricted
+** the same way.
+**
+** Nick logic remains the same.  Anything listed in a resv{} will prevent
+** that nick from being used.
+*/
 resv {
         /* reason: the reason for the proceeding resv's */
         reason = "There are no services on this network";
 
-	/* resv: the nicks and channels users may not join/use */
+	/* resv: the nicks users may not use */
 	nick = "nickserv";
 	nick = "chanserv";
+
+	/* resv: the channels users MAY use, all others are blocked */
 	channel = "#services";
+	channel = "#network";
 
 	/* resv: wildcard masks are also supported in nicks only */
 	reason = "Clone bots";
diff -uNrd ircd-ratbox-1.1rc5.dist/include/patchlevel.h ircd-ratbox-1.1rc5/include/patchlevel.h
--- ircd-ratbox-1.1rc5.dist/include/patchlevel.h	Wed Apr  2 06:41:56 2003
+++ ircd-ratbox-1.1rc5/include/patchlevel.h	Wed Apr 16 21:05:30 2003
@@ -25,5 +25,5 @@
  */
 
 #ifndef PATCHLEVEL
-#define PATCHLEVEL   "ircd-ratbox-1.1rc5"
+#define PATCHLEVEL   "ircd-ratbox-1.1rc5+revjupe"
 #endif
diff -uNrd ircd-ratbox-1.1rc5.dist/modules/m_join.c ircd-ratbox-1.1rc5/modules/m_join.c
--- ircd-ratbox-1.1rc5.dist/modules/m_join.c	Wed Feb 12 11:59:39 2003
+++ ircd-ratbox-1.1rc5/modules/m_join.c	Wed Apr 16 21:06:19 2003
@@ -127,12 +127,12 @@
 		}
 
 		/* see if its resv'd */
-		if(find_channel_resv(name) && (!IsOper(source_p) || !ConfigChannel.no_oper_resvs))
+		if((find_channel_resv(name) == 0) && (!IsOper(source_p) || !ConfigChannel.no_oper_resvs))
 		{
 			sendto_one(source_p, form_str(ERR_UNAVAILRESOURCE),
 				   me.name, source_p->name, name);
 			sendto_realops_flags(UMODE_SPY, L_ALL,
-					     "User %s (%s@%s) is attempting to join locally juped channel %s",
+                                             "User %s (%s@%s) is attempting to join blocked channel %s",
 					     source_p->name, source_p->username, source_p->host,
 					     name);
 			continue;
diff -uNrd ircd-ratbox-1.1rc5.dist/src/channel.c ircd-ratbox-1.1rc5/src/channel.c
--- ircd-ratbox-1.1rc5.dist/src/channel.c	Thu Mar 27 19:07:14 2003
+++ ircd-ratbox-1.1rc5/src/channel.c	Wed Apr 16 21:07:20 2003
@@ -976,7 +976,7 @@
 int
 can_send(struct Channel *chptr, struct Client *source_p)
 {
-	if(MyClient(source_p) && find_channel_resv(chptr->chname) &&
+	if(MyClient(source_p) && (find_channel_resv(chptr->chname) == 0) &&
 	   (!IsOper(source_p) || !ConfigChannel.no_oper_resvs))
 		return CAN_SEND_NO;
 
